@@ -33,9 +33,10 @@
 #  define KWINXRENDERUTILS_DEPRECATED_NO_EXPORT KWINXRENDERUTILS_NO_EXPORT KWINXRENDERUTILS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KWINXRENDERUTILS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KWINXRENDERUTILS_NO_DEPRECATED
+#    define KWINXRENDERUTILS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
